summaryrefslogtreecommitdiff
path: root/sqlbox/version.php
diff options
context:
space:
mode:
Diffstat (limited to 'sqlbox/version.php')
-rw-r--r--sqlbox/version.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/sqlbox/version.php b/sqlbox/version.php
index dc1f915..1c8578a 100644
--- a/sqlbox/version.php
+++ b/sqlbox/version.php
@@ -17,13 +17,13 @@
/**
* Defines the version of newmodule
*
* This code fragment is called by moodle_needs_upgrading() and
* /admin/index.php
*
* @package mod
- * @subpackage newmodule
+ * @subpackage sqlbox
* @copyright 2011 Your Name
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -34,4 +34,4 @@ $module->version = 0; // If version == 0 then module will not be
//$module->version = 2010032200; // The current module version (Date: YYYYMMDDXX)
$module->requires = 2010031900; // Requires this Moodle version
$module->cron = 0; // Period for cron to check this module (secs)
-$module->component = 'mod_newmodule'; // To check on upgrade, that module sits in correct place
+$module->component = 'mod_sqlbox'; // To check on upgrade, that module sits in correct place
@@ -17,13 +17,13 @@
/**
- * Defines the version of newmodule
+ * Defines the version of sqlbox
*
* This code fragment is called by moodle_needs_upgrading() and